@@ -1,13 +1,15 @@
 package Dist::Zilla::Plugin::Rinci::Wrap;
 
+our $DATE = '2015-02-26'; # DATE
+our $VERSION = '0.08'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 
+use Data::Dmp::Meta ();
 use Perinci::Sub::Wrapper qw(wrap_sub);
 
-our $VERSION = '0.07'; # VERSION
-
 use Moose;
 use experimental 'smartmatch';
 use namespace::autoclean;
@@ -222,7 +224,8 @@ sub munge_file {
                 next;
             }
             # put modify-meta code
-            my $presub2 = $self->_squish_code($wres{$sub_name}{source}{presub2});
+            #my $presub2 = $self->_squish_code($wres{$sub_name}{source}{presub2});
+            my $presub2 = "\$SPEC{$sub_name} = " . Data::Dmp::Meta::dmp({old_data=>"\$SPEC{$sub_name}"}, $wres{$sub_name}{meta}) . ";";
             if ($presub2 =~ /\S/) {
                 $_ = "\n$1# [Rinci::Wrap] END presub2\n$_" if $self->debug;
                 $_ = "$presub2 $_";
@@ -328,7 +331,7 @@ Dist::Zilla::Plugin::Rinci::Wrap - Insert wrapper-generated code
 
 =head1 VERSION
 
-This document describes version 0.07 of Dist::Zilla::Plugin::Rinci::Wrap (from Perl distribution Dist-Zilla-Plugin-Rinci-Wrap), released on 2015-02-25.
+This document describes version 0.08 of Dist::Zilla::Plugin::Rinci::Wrap (from Perl distribution Dist-Zilla-Plugin-Rinci-Wrap), released on 2015-02-26.
 
 =head1 SYNOPSIS
 
